@@ -17,6 +17,7 @@ pub(crate) use rapier2d as rapier;
 pub(crate) use rapier3d as rapier;
 
 use heron_core::{CollisionEvent, PhysicsSystem};
+pub use pipeline::{PhysicsWorld, RayCastInfo, ShapeCastCollisionInfo, ShapeCastCollisionType};
 
 use crate::rapier::dynamics::{
     CCDSolver, IntegrationParameters, IslandManager, JointSet, RigidBodySet,
@@ -29,7 +30,6 @@ mod acceleration;
 mod body;
 pub mod convert;
 mod pipeline;
-pub use pipeline::{PhysicsWorld, RayCastInfo, ShapeCastCollisionInfo, ShapeCastCollisionType};
 mod shape;
 mod velocity;
 
@@ -110,11 +110,6 @@ fn create_collider_stage() -> SystemStage {
 fn step_systems() -> SystemSet {
     SystemSet::new()
         .with_run_criteria(heron_core::should_run.system())
-        .with_system(
-            velocity::apply_velocity_to_kinematic_bodies
-                .system()
-                .before(PhysicsSystem::Events),
-        )
         .with_system(
             pipeline::update_integration_parameters
                 .system()
@@ -133,4 +128,10 @@ fn step_systems() -> SystemSet {
                 .label(PhysicsSystem::VelocityUpdate)
                 .after(PhysicsSystem::Events),
         )
+        .with_system(
+            velocity::update_rapier_velocity
+                .system()
+                .after(PhysicsSystem::Events)
+                .after(PhysicsSystem::VelocityUpdate),
+        )
 }
